@@ -19,9 +19,12 @@ refer to dice in a pool.
 
 __docformat__ = 'google'
 
-from icepool.constant import SpecialValue
+from typing import Final
 
-Reroll = SpecialValue.Reroll
+from icepool.constant import Order, RerollType
+from icepool.typing import Outcome
+
+Reroll: Final = RerollType.Reroll
 """Indicates that an outcome should be rerolled (with unlimited depth).
 
 This can be used in place of outcomes in many places. See individual function
@@ -44,41 +47,45 @@ Operation in specific cases:
 
 # Expose certain names at top-level.
 
-from icepool.die.func import (standard, d, __getattr__, bernoulli, coin,
-                              one_hot, from_cumulative_quantities, from_rv,
-                              min_outcome, max_outcome, align, align_range,
-                              reduce, accumulate, apply, apply_sorted)
+from icepool.population.func import (standard, d, __getattr__, bernoulli, coin,
+                                     one_hot, cartesian_product,
+                                     from_cumulative_quantities, from_rv,
+                                     min_outcome, max_outcome, align,
+                                     align_range, reduce, accumulate, apply,
+                                     apply_sorted)
 
-from icepool.population import Population
-from icepool.die.die import implicit_convert_to_die, Die
-from icepool.again import Again
-from icepool.die.die_with_truth import DieWithTruth
+from icepool.population.base import Population
+from icepool.population.die import implicit_convert_to_die, Die
+from icepool.population.again import Again
+from icepool.population.die_with_truth import DieWithTruth
 
 from icepool.counts import CountsKeysView, CountsValuesView, CountsItemsView
 
-from icepool.die.lowest_highest import lowest, highest
+from icepool.population.lowest_highest import sum_lowest, sum_highest
 
-from icepool.pool import Pool, standard_pool, clear_pool_cache
-from icepool.outcome_count_generator import OutcomeCountGenerator, NextOutcomeCountGenerator
-from icepool.outcome_count_evaluator import OutcomeCountEvaluator, Order
-from icepool.evaluators import (
+from icepool.generator.pool import Pool, standard_pool, clear_pool_cache
+from icepool.generator.outcome_count_generator import OutcomeCountGenerator, NextOutcomeCountGenerator
+from icepool.evaluator.outcome_count_evaluator import OutcomeCountEvaluator
+from icepool.evaluator.evaluators import (
     WrapFuncEvaluator, JointEvaluator, SumEvaluator, sum_evaluator,
     ExpandEvaluator, expand_evaluator, CountInEvaluator, count_unique_evaluator,
     SubsetTargetEvaluator, ContainsSubsetEvaluator, IntersectionSizeEvaluator,
-    BestMatchingSetEvaluator, best_matching_set_evaluator,
-    BestStraightEvaluator, best_straight_evaluator)
+    LargestMatchingSetEvaluator, LargestMatchingSetAndOutcomeEvaluator,
+    AllMatchingSetsEvaluator, LargestStraightEvaluator,
+    LargestStraightAndOutcomeEvaluator)
 
-from icepool.deck import Deck
-from icepool.deal import Deal
+from icepool.population.deck import Deck
+from icepool.generator.deal import Deal
 
-from icepool.generators import SuitGenerator
+from icepool.generator.generators import SuitGenerator
 
 __all__ = [
-    'standard', 'd', 'bernoulli', 'coin', 'one_hot', 'Die', 'Population',
-    'Again', 'CountsKeysView', 'CountsValuesView', 'CountsItemsView',
-    'from_cumulative_quantities', 'from_rv', 'align', 'align_range', 'lowest',
-    'highest', 'min_outcome', 'max_outcome', 'reduce', 'accumulate', 'apply',
-    'apply_sorted', 'Reroll', 'Unlimited', 'OutcomeCountGenerator', 'Pool',
+    'standard', 'd', 'bernoulli', 'coin', 'one_hot', 'cartesian_product',
+    'Outcome', 'Die', 'Population', 'Again', 'CountsKeysView',
+    'CountsValuesView', 'CountsItemsView', 'from_cumulative_quantities',
+    'from_rv', 'align', 'align_range', 'sum_lowest', 'sum_highest',
+    'min_outcome', 'max_outcome', 'reduce', 'accumulate', 'apply',
+    'apply_sorted', 'Reroll', 'RerollType', 'OutcomeCountGenerator', 'Pool',
     'standard_pool', 'OutcomeCountEvaluator', 'Order', 'JointEvaluator',
     'SumEvaluator', 'ExpandEvaluator', 'Deck', 'Deal', 'SuitGenerator',
     'clear_pool_cache'
